==> xoonips-3.42a.zip: xoonips-3.42a/itemtypes/xnpbinder/language/japanese/modinfo.php <==
<?php
// $Revision: 1.1.1.2 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
define("_MI_XNPBINDER_NAME","XooNIps Binder Item Type Module");
define("_MI_XNPBINDER_DESC","XooNIps Binder Item Type Module");
define( "_MI_XNPBINDER_CONTENT_EMPTY_NOTIFY", "ΥХ" );
define( "_MI_XNPBINDER_CONTENT_EMPTY_NOTIFYCAP", "ХˤʤäΤ" );
define( "_MI_XNPBINDER_CONTENT_EMPTY_NOTIFYDSC", "ХϿ줿ƥब0ĤˤʤäΤ롥" );
define( "_MI_XNPBINDER_CONTENT_EMPTY_NOTIFYSBJ", "Хˤʤޤ" );
?>

==> xoonips-3.49.zip: xoonips-3.49/itemtypes/xnpbinder/language/japanese/modinfo.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
define('_MI_XNPBINDER_NAME', 'XooNIps Binder Item Type Module');
define('_MI_XNPBINDER_DESC', 'XooNIps Binder Item Type Module');
define('_MI_XNPBINDER_CONTENT_EMPTY_NOTIFY', 'ΥХ');
define('_MI_XNPBINDER_CONTENT_EMPTY_NOTIFYCAP', 'ХˤʤäΤ');
define('_MI_XNPBINDER_CONTENT_EMPTY_NOTIFYDSC', 'ХϿ줿ƥब0ĤˤʤäΤ롥');
define('_MI_XNPBINDER_CONTENT_EMPTY_NOTIFYSBJ', 'Хˤʤޤ');
